==> SampLin-1.3.1.tar.gz: SampLin-1.3.1/src/ui/PrefComp.cpp <==
/**************************************************************************
 * $Id: PrefComp.cpp 1.1 Thu, 03 Dec 1998 12:49:42 +0100 samo $
 * $ReleaseVersion: 1.3.1 $
 *
 * This file is part of SampLin data acquisition software
 * Copyright (C) 1997,98 Samuel Kvasnica
 *
 * SampLin is free software; you can redistribute it and/or modify it
 * under the terms of the version 2 of GNU General Public License as
 * published by the Free Software Foundation.
 *
 * SampLin is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * (see the file LICENSE) along with SampLin package; if not, write to the
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **************************************************************************/

#include "PrefComp.h"

#include <samplin.h>

#include "PrefComp.moc"


#define Inherited PrefCompData

PrefComp::PrefComp
(
	QWidget* parent,
	const char* name
)
	:
	Inherited( parent, name )
{
}


PrefComp::~PrefComp()
{
}

void PrefComp::setData(struct configstruct *cfg)
{

   cnf=cfg;
   input_level->setCurrentItem(cnf->info_level-1);
   input_messages->setCurrentItem(1-cnf->mesg_win);
   
}

void PrefComp::apply()
{
   cnf->info_level=input_level->currentItem()+1;
   cnf->mesg_win=!(input_messages->currentItem());
}

==> SampLin-1.5.0.tar.gz: SampLin-1.5.0/src/ui/PrefComp.cpp <==
/**************************************************************************
 * $Id: PrefComp.cpp 1.1 Thu, 03 Dec 1998 12:49:42 +0100 samo $
 * $ReleaseVersion: 1.3.1 $
 *
 * This file is part of SampLin data acquisition software
 * Copyright (C) 1997,98 Samuel Kvasnica
 *
 * SampLin is free software; you can redistribute it and/or modify it
 * under the terms of the version 2 of GNU General Public License as
 * published by the Free Software Foundation.
 *
 * SampLin is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * (see the file LICENSE) along with SampLin package; if not, write to the
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **************************************************************************/

#include "PrefComp.h"

#include <cnflib.h>

#include "PrefComp.moc"


#define Inherited PrefCompData

PrefComp::PrefComp
(
	QWidget* parent,
	const char* name
)
	:
	Inherited( parent, name )
{
}


PrefComp::~PrefComp()
{
}

void PrefComp::setData(struct configstruct *cfg)
{

   cnf=cfg;
   input_level->setCurrentItem(cnf->info_level-1);
   input_messages->setCurrentItem(1-cnf->mesg_win);
   input_timestamp->setChecked(cnf->mesg_time);
   input_autosave->setChecked(cnf->auto_save);
}

void PrefComp::apply()
{
   cnf->info_level=input_level->currentItem()+1;
   cnf->mesg_win=!(input_messages->currentItem());
   cnf->mesg_time=input_timestamp->isChecked();
   cnf->auto_save=input_autosave->isChecked();
}
